@@ -179,7 +179,7 @@ resource "aws_ami" "example" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			block := createBlocksFromSource(test.source)[0]
+			block := CreateBlocksFromSource(test.source)[0]
 			result := evalMatchSpec(block, &test.predicateMatchSpec, nil)
 			assert.Equal(t, result, test.expected, "`Or` match function evaluating incorrectly.")
 		})
@@ -226,7 +226,7 @@ resource "aws_ami" "example" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := createBlocksFromSource(test.source)[0]
+			blocks := CreateBlocksFromSource(test.source)[0]
 			result := evalMatchSpec(blocks, &test.predicateMatchSpec, nil)
 			assert.Equal(t, result, test.expected, "`And` match function evaluating incorrectly.")
 		})
@@ -276,7 +276,7 @@ resource "aws_ami" "example" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := createBlocksFromSource(test.source)[0]
+			blocks := CreateBlocksFromSource(test.source)[0]
 			result := evalMatchSpec(blocks, &test.predicateMatchSpec, nil)
 			assert.Equal(t, result, test.expected, "Nested match functions evaluating incorrectly.")
 		})
@@ -303,7 +303,7 @@ resource "aws_ami" "example" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := createBlocksFromSource(test.source)[0]
+			blocks := CreateBlocksFromSource(test.source)[0]
 			result := evalMatchSpec(blocks, &test.matchSpec, nil)
 			assert.Equal(t, result, test.expected, "Not match functions evaluating incorrectly.")
 		})
@@ -333,7 +333,7 @@ func scanTerraform(t *testing.T, mainTf string) []result.Result {
 
 // This function is copied from setup_test.go as it is not possible to import function from test files.
 // TODO: Extract into a testing utility package once the amount of duplication justifies introducing an extra package.
-func createBlocksFromSource(source string) []block.Block {
+func CreateBlocksFromSource(source string) []block.Block {
 	path := createTestFile("test.tf", source)
 	blocks, err := parser.New(filepath.Dir(path), parser.OptionStopOnHCLError()).ParseDirectory()
 	if err != nil {
