@@ -1,8 +1,7 @@
 package cloudtrail
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -67,21 +66,18 @@ resource "aws_cloudtrail" "good_example" {
 		RequiredLabels:  []string{"aws_cloudtrail"},
 		DefaultSeverity: severity.Medium,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
+
 			if resourceBlock.MissingChild("is_multi_region_trail") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not set multi region trail config.", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not set multi region trail config.", resourceBlock.FullName())
 				return
 			}
 
 			multiRegionAttr := resourceBlock.GetAttribute("is_multi_region_trail")
 			if multiRegionAttr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not enable multi region trail.", resourceBlock.FullName())).
-						WithAttribute(multiRegionAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not enable multi region trail.", resourceBlock.FullName()).
+					WithAttribute(multiRegionAttr)
 			}
 		},
 	})
