@@ -1,11 +1,13 @@
 package ecs
 
+// generator-locked
 import (
 	"encoding/json"
-	"fmt"
+	"strings"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
+	"github.com/zclconf/go-cty/cty"
 
 	"github.com/aquasecurity/tfsec/pkg/provider"
 
@@ -19,8 +21,6 @@ import (
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/security"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
-
-	"github.com/zclconf/go-cty/cty"
 )
 
 func init() {
@@ -82,8 +82,8 @@ EOF
 		DefaultSeverity: severity.Critical,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
-			if definitionsAttr := resourceBlock.GetAttribute("container_definitions"); definitionsAttr != nil && definitionsAttr.Type() == cty.String {
-				rawJSON := []byte(definitionsAttr.Value().AsString())
+			if definitionsAttr := resourceBlock.GetAttribute("container_definitions"); definitionsAttr.IsNotNil() && definitionsAttr.Type() == cty.String {
+				rawJSON := strings.TrimSpace(definitionsAttr.Value().AsString())
 
 				var definitions []struct {
 					EnvVars []struct {
@@ -92,7 +92,8 @@ EOF
 					} `json:"environment"`
 				}
 
-				if err := json.Unmarshal(rawJSON, &definitions); err != nil {
+				err := json.Unmarshal([]byte(rawJSON), &definitions)
+				if err != nil {
 					debug.Log("an error occurred processing container definition json: %s: %s", resourceBlock.Range(), err.Error())
 					return
 				}
@@ -100,10 +101,8 @@ EOF
 				for _, definition := range definitions {
 					for _, env := range definition.EnvVars {
 						if security.IsSensitiveAttribute(env.Name) && env.Value != "" {
-							set.Add(result.New(resourceBlock).
-								WithDescription(fmt.Sprintf("Resource '%s' includes a potentially sensitive environment variable '%s' in the container definition.", resourceBlock.FullName(), env.Name)).
-								WithAttribute(definitionsAttr),
-							)
+							set.AddResult().WithDescription("Resource '%s' includes a potentially sensitive environment variable '%s' in the container definition.", resourceBlock.FullName(), env.Name).
+								WithAttribute(definitionsAttr)
 						}
 					}
 				}
