@@ -1,8 +1,7 @@
 package elasticsearch
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -14,8 +13,6 @@ import (
 
 	"github.com/aquasecurity/tfsec/pkg/rule"
 
-	"github.com/zclconf/go-cty/cty"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
 )
 
@@ -61,32 +58,23 @@ resource "aws_elasticsearch_domain" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, context *hclcontext.Context) {
 
 			encryptionBlock := resourceBlock.GetBlock("node_to_node_encryption")
-			if encryptionBlock == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines an Elasticsearch domain with plaintext traffic (missing node_to_node_encryption block).", resourceBlock.FullName())),
-				)
+			if encryptionBlock.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines an Elasticsearch domain with plaintext traffic (missing node_to_node_encryption block).", resourceBlock.FullName())
 				return
 			}
 
 			enabledAttr := encryptionBlock.GetAttribute("enabled")
-			if enabledAttr == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines an Elasticsearch domain with plaintext traffic (missing enabled attribute).", resourceBlock.FullName())),
-				)
+			if enabledAttr.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines an Elasticsearch domain with plaintext traffic (missing enabled attribute).", resourceBlock.FullName())
 				return
 			}
 
-			isTrueBool := enabledAttr.Type() == cty.Bool && enabledAttr.Value().True()
-			isTrueString := enabledAttr.Type() == cty.String &&
-				enabledAttr.Value().Equals(cty.StringVal("true")).True()
-			nodeToNodeEncryptionEnabled := isTrueBool || isTrueString
-			if !nodeToNodeEncryptionEnabled {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines an Elasticsearch domain with plaintext traffic (enabled attribute set to false).", resourceBlock.FullName())),
-				)
+			if enabledAttr.IsFalse() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines an Elasticsearch domain with plaintext traffic (enabled attribute set to false).", resourceBlock.FullName()).
+					WithAttribute(enabledAttr)
 			}
 
 		},
