@@ -1,8 +1,7 @@
 package rds
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -59,19 +58,15 @@ resource "aws_rds_cluster_instance" "good_example" {
 
 			if resourceBlock.HasChild("performance_insights_enabled") && resourceBlock.GetAttribute("performance_insights_enabled").IsTrue() {
 				if resourceBlock.MissingChild("performance_insights_kms_key_id") {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' defines Performance Insights without encryption key specified.", resourceBlock.FullName())),
-					)
+					set.AddResult().
+						WithDescription("Resource '%s' defines Performance Insights without encryption key specified.", resourceBlock.FullName())
 					return
 				}
 
 				if keyAttr := resourceBlock.GetAttribute("performance_insights_kms_key_id"); keyAttr.IsEmpty() {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' defines Performance Insights without encryption key specified.", resourceBlock.FullName())).
-							WithAttribute(keyAttr),
-					)
+					set.AddResult().
+						WithDescription("Resource '%s' defines Performance Insights without encryption key specified.", resourceBlock.FullName()).
+						WithAttribute(keyAttr)
 				}
 			}
 
