@@ -1,8 +1,7 @@
 package sqs
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -14,8 +13,6 @@ import (
 
 	"github.com/aquasecurity/tfsec/pkg/rule"
 
-	"github.com/zclconf/go-cty/cty"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
 )
 
@@ -53,18 +50,14 @@ resource "aws_sqs_queue" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, context *hclcontext.Context) {
 
 			kmsKeyIDAttr := resourceBlock.GetAttribute("kms_master_key_id")
-			if kmsKeyIDAttr == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines an unencrypted SQS queue.", resourceBlock.FullName())),
-				)
+			if kmsKeyIDAttr.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines an unencrypted SQS queue.", resourceBlock.FullName())
 
-			} else if kmsKeyIDAttr.Type() == cty.String && kmsKeyIDAttr.Value().AsString() == "" {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines an unencrypted SQS queue.", resourceBlock.FullName())).
-						WithAttribute(kmsKeyIDAttr),
-				)
+			} else if kmsKeyIDAttr.IsEmpty() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines an unencrypted SQS queue.", resourceBlock.FullName()).
+					WithAttribute(kmsKeyIDAttr)
 			}
 
 		},
