@@ -1,8 +1,7 @@
 package vpc
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -49,10 +48,8 @@ resource "aws_default_vpc" "default" {
 		RequiredLabels:  []string{"aws_default_vpc"},
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
-			set.Add(
-				result.New(resourceBlock).
-					WithDescription(fmt.Sprintf("Resource '%s' should not exist", resourceBlock.FullName())),
-			)
+			set.AddResult().
+				WithDescription("Resource '%s' should not exist", resourceBlock.FullName())
 		},
 	})
 }
