@@ -1,8 +1,7 @@
 package storage
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -64,11 +63,14 @@ resource "azurerm_storage_account" "good_example" {
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
-			if resourceBlock.HasChild("enable_https_traffic_only") && resourceBlock.GetAttribute("enable_https_traffic_only").IsFalse() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' explicitly turns off secure transfer to storage account.", resourceBlock.FullName())),
-				)
+			if resourceBlock.HasChild("enable_https_traffic_only") {
+
+				httpsOnlyAttr := resourceBlock.GetAttribute("enable_https_traffic_only")
+
+				if httpsOnlyAttr.IsFalse() {
+					set.AddResult().
+						WithDescription("Resource '%s' explicitly turns off secure transfer to storage account.", resourceBlock.FullName())
+				}
 			}
 
 		},
