@@ -1,8 +1,7 @@
 package compute
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/cidr"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
@@ -69,11 +68,9 @@ resource "digitalocean_firewall" "good_example" {
 				}
 				destinationAddressesAttr := inboundRuleBlock.GetAttribute("destination_addresses")
 				if cidr.IsOpen(destinationAddressesAttr) {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' defines a fully open outbound_rule.", resourceBlock.FullName())).
-							WithAttribute(destinationAddressesAttr),
-					)
+					set.AddResult().
+						WithDescription("Resource '%s' defines a fully open outbound_rule.", resourceBlock.FullName()).
+						WithAttribute(destinationAddressesAttr)
 				}
 			}
 		},
