@@ -1,8 +1,7 @@
 package sql
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -22,10 +21,10 @@ func init() {
 		Service:   "sql",
 		ShortCode: "encrypt-in-transit-data",
 		Documentation: rule.RuleDocumentation{
-			Summary: "SSL connections to a SQL database instance should be enforced.",
-			Explanation: `	`,
-			Impact:     "Intercepted data can be read in transit",
-			Resolution: "Enforce SSL for all connections",
+			Summary:     "SSL connections to a SQL database instance should be enforced.",
+			Explanation: `In-transit data should be encrypted so that if traffic is intercepted data will not be exposed in plaintext to attackers.`,
+			Impact:      "Intercepted data can be read in transit",
+			Resolution:  "Enforce SSL for all connections",
 			BadExample: []string{`
 resource "google_sql_database_instance" "postgres" {
 	name             = "postgres-instance-a"
@@ -64,7 +63,10 @@ resource "google_sql_database_instance" "postgres" {
 	}
 }
 			`},
-			Links: []string{"https://cloud.google.com/sql/docs/mysql/configure-ssl-instance"},
+			Links: []string{
+				"https://registry.terraform.io/providers/hashicorp/google/latest/docs/resources/sql_database_instance",
+				"https://cloud.google.com/sql/docs/mysql/configure-ssl-instance",
+			},
 		},
 		Provider:        provider.GoogleProvider,
 		RequiredTypes:   []string{"resource"},
@@ -73,30 +75,24 @@ resource "google_sql_database_instance" "postgres" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			settingsBlock := resourceBlock.GetBlock("settings")
-			if settingsBlock == nil {
+			if settingsBlock.IsNil() {
 				return
 			}
 
 			ipConfigBlock := settingsBlock.GetBlock("ip_configuration")
-			if ipConfigBlock == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not require SSL for all connections", resourceBlock.FullName())),
-				)
+			if ipConfigBlock.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' does not require SSL for all connections", resourceBlock.FullName())
 				return
 			}
 
-			if requireSSLAttr := ipConfigBlock.GetAttribute("require_ssl"); requireSSLAttr == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not require SSL for all connections", resourceBlock.FullName())),
-				)
+			if requireSSLAttr := ipConfigBlock.GetAttribute("require_ssl"); requireSSLAttr.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' does not require SSL for all connections", resourceBlock.FullName())
 			} else if requireSSLAttr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).
-						WithAttribute(requireSSLAttr).
-						WithDescription(fmt.Sprintf("Resource '%s' explicitly does not require SSL for all connections", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithAttribute(requireSSLAttr).
+					WithDescription("Resource '%s' explicitly does not require SSL for all connections", resourceBlock.FullName())
 			}
 
 		},
