@@ -1,8 +1,7 @@
 package compute
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -53,14 +52,10 @@ resource "opc_compute_ip_address_reservation" "good_example" {
 		RequiredLabels:  []string{"opc_compute_ip_address_reservation"},
 		DefaultSeverity: severity.Critical,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
-			if attr := resourceBlock.GetAttribute("ip_address_pool"); attr != nil {
-				if attr.Equals("public-ippool") {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' is using an IP from a public IP pool", resourceBlock.FullName())).
-							WithAttribute(attr),
-					)
-				}
+			if attr := resourceBlock.GetAttribute("ip_address_pool"); attr.Equals("public-ippool") {
+				set.AddResult().
+					WithDescription("Resource '%s' is using an IP from a public IP pool", resourceBlock.FullName()).
+					WithAttribute(attr)
 			}
 		},
 	})
