@@ -2,6 +2,8 @@ package security
 
 import (
 	"strings"
+
+	"github.com/owenrumney/squealer/pkg/squealer"
 )
 
 var sensitiveAttributeTokens = []string{
@@ -14,6 +16,10 @@ var sensitiveAttributeTokens = []string{
 	"api_key",
 }
 
+var sensitiveAttributes = map[string]string{}
+
+var StringScanner = squealer.NewStringScanner()
+
 var whitelistTokens = []string{
 	"version",
 }
