@@ -63,7 +63,7 @@ func (r *Result) Range() block.Range {
 	if r.attribute != nil {
 		return r.attribute.Range()
 	}
-	return r.blocks[0].Range()
+	return r.blocks[len(r.blocks)-1].Range()
 }
 
 func (r *Result) HashCode() string {
@@ -122,8 +122,13 @@ func (r *Result) WithBlock(block block.Block) *Result {
 	return r
 }
 
-func (r *Result) WithDescription(description string) *Result {
-	r.Description = description
+func (r *Result) WithDescription(description string, parts ...interface{}) *Result {
+	if len(parts) == 0 {
+		r.Description = description
+	} else {
+		r.Description = fmt.Sprintf(description, parts...)
+	}
+
 	return r
 }
 
@@ -139,6 +144,10 @@ func (r *Result) WithStatus(status Status) *Result {
 
 func (r *Result) WithAttribute(attr block.Attribute) *Result {
 
+	if attr.IsNil() {
+		return r
+	}
+
 	r.attribute = attr
 
 	var raw string
@@ -183,5 +192,6 @@ func (r *Result) WithAttribute(attr block.Attribute) *Result {
 	}
 
 	r.RangeAnnotation = fmt.Sprintf("%s: %s", typeStr, raw)
+	r.Location = r.Range()
 	return r
 }
