@@ -2,6 +2,7 @@ package rule
 
 import (
 	"fmt"
+	"strings"
 
 	"github.com/aquasecurity/tfsec/pkg/provider"
 	"github.com/aquasecurity/tfsec/pkg/result"
@@ -28,7 +29,7 @@ type Rule struct {
 }
 
 func (r Rule) ID() string {
-	return fmt.Sprintf("%s-%s-%s", r.Provider, r.Service, r.ShortCode)
+	return strings.ToLower(fmt.Sprintf("%s-%s-%s", r.Provider, r.Service, r.ShortCode))
 }
 
 func (r Rule) MatchesID(id string) bool {
